package com.sun.tools.javac.resources;

public final class version extends java.util.ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "full", "11.0.6+9-jvmci-19.3-b07" },
            { "jdk", "11.0.6" },
            { "release", "11.0.6" },
        };
    }
}
